@@ -22,9 +22,9 @@ use tokio::{
     sync::{mpsc, watch, RwLock},
 };
 use tokio_util::codec::{FramedRead, FramedWrite};
-use tracing::trace;
+use tracing::{error, trace};
 
-pub use config::Config;
+pub use config::StreamMultiplexorConfig;
 use frame::{FrameDecoder, FrameEncoder};
 use inner::StreamMultiplexorInner;
 pub use listener::MuxListener;
@@ -52,14 +52,29 @@ impl<T> Drop for StreamMultiplexor<T> {
 }
 
 impl<T: AsyncRead + AsyncWrite + Send + Unpin + 'static> StreamMultiplexor<T> {
-    /// Constructs a new StreamMultiplexor<T>
-    pub fn new(inner: T, config: Config) -> Self {
+    /// Constructs a new `StreamMultiplexor<T>`
+    pub fn new(inner: T, config: StreamMultiplexorConfig) -> Self {
+        Self::new_running(inner, config, true)
+    }
+
+    /// Constructs a new paused `StreamMultiplexor<T>`
+    ///
+    /// This allows you to bind and listen on a bunch of ports before
+    /// processing any packets from the inner stream, removing race conditions
+    /// between bind and connect. Call `start()` to start processing the
+    /// inner stream.
+    pub fn new_paused(inner: T, config: StreamMultiplexorConfig) -> Self {
+        Self::new_running(inner, config, false)
+    }
+
+    fn new_running(inner: T, config: StreamMultiplexorConfig, running: bool) -> Self {
         let (reader, writer) = split(inner);
 
         let framed_reader = FramedRead::new(reader, FrameDecoder::new(config));
         let framed_writer = FramedWrite::new(writer, FrameEncoder::new(config));
         let (send, recv) = mpsc::channel(10);
         let (watch_connected_send, _) = watch::channel(true);
+        let (running, _) = watch::channel(running);
         let inner = Arc::from(StreamMultiplexorInner {
             config,
             connected: AtomicBool::from(true),
@@ -67,6 +82,7 @@ impl<T: AsyncRead + AsyncWrite + Send + Unpin + 'static> StreamMultiplexor<T> {
             port_listeners: RwLock::from(HashMap::new()),
             watch_connected_send,
             send: RwLock::from(send),
+            running,
         });
 
         tokio::spawn(inner.clone().framed_writer_sender(recv, framed_writer));
@@ -75,6 +91,16 @@ impl<T: AsyncRead + AsyncWrite + Send + Unpin + 'static> StreamMultiplexor<T> {
         Self { inner }
     }
 
+    /// Start processing the inner stream.
+    ///
+    /// Only effective on a paused `StreamMultiplexor<T>`.
+    /// See `new_paused(inner: T, config: StreamMultiplexorConfig)`.
+    pub fn start(&self) {
+        if let Err(error) = self.inner.running.send(true) {
+            error!("Error {:?} setting running to true", error);
+        }
+    }
+
     /// Bind to port and return a `MuxListener<T>`
     #[tracing::instrument]
     pub async fn bind(&self, port: u16) -> Result<MuxListener<T>> {
